# #source https://github.com/tuxedocomputers/tuxedo-keyboard

%global		module tuxedo_keyboard
%define		pname tuxedo-keyboard

Name:		dkms-%{pname}
Version:	3.0.10
Release:	%mkrel 1
Source0:	%{pname}-%{version}.tar.xz

Patch0:		%{pname}-%{version}-makefile.patch

License:	GPLv2
Group:		System/Kernel and hardware
URL:		https://github.com/tuxedocomputers/tuxedo-keyboard

Summary:	dkms package for %{module} driver

Provides:	%{name} = %{version}
 
Requires(post,preun): dkms

BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot

Obsoletes:	%{pname} <= %{version}

%description
TUXEDO Computers kernel module drivers for keyboard, keyboard backlight &
general hardware I/O
Features
    Driver for Fn-keys
    Sysfs control of brightness/color/mode for most TUXEDO keyboards
			(note: white backlight only models are currently not supported)
    Hardware I/O driver for TUXEDO Control Center
Modules included in this package
    tuxedo-keyboard
    tuxedo-io
    clevo-wmi
    clevo-acpi

%prep
%setup -qn %{pname}-%{version}
%apply_patches

find -type f -exec chmod 0644 {} \;

%install
%__rm -rf %{buildroot}
%__mkdir -p %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}
%__cp -a ./{CHANGELOG.md,README.md,LICENSE,Makefile} %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}
%__cp -a ./src/{*c,*h} %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}
%__cp -a ./src/tuxedo_io/{*c,*h} %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}
%__mkdir -p %{buildroot}%{_sysconfdir}/modprobe.d
%__cp -a ./tuxedo_keyboard.conf %{buildroot}%{_sysconfdir}/modprobe.d/

# just to keep:  BUILT_MODULE_LOCATION[0]="./"
cat <<EOF > %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}/dkms.conf
PACKAGE_NAME="%{pname}"
PACKAGE_VERSION="%{version}-%{release}"
BUILT_MODULE_NAME[0]="tuxedo_keyboard"
DEST_MODULE_LOCATION[0]="/kernel/3rdparty/tuxedo"
BUILT_MODULE_LOCATION[0]="./"
BUILT_MODULE_NAME[1]="clevo_wmi"
DEST_MODULE_LOCATION[1]="/kernel/3rdparty/tuxedo"
BUILT_MODULE_LOCATION[1]="./"
BUILT_MODULE_NAME[2]="clevo_acpi"
DEST_MODULE_LOCATION[2]="/kernel/3rdparty/tuxedo"
BUILT_MODULE_LOCATION[2]="./"
BUILT_MODULE_NAME[3]="tuxedo_io"
DEST_MODULE_LOCATION[3]="/kernel/3rdparty/tuxedo"
BUILT_MODULE_LOCATION[3]="./"
BUILT_MODULE_NAME[4]="uniwill_wmi"
DEST_MODULE_LOCATION[4]="/kernel/3rdparty/tuxedo"
BUILT_MODULE_LOCATION[4]="./"
MAKE[0]="export IGNORE_CC_MISMATCH=1; 'make' KSRC=\${kernel_source_dir} SKIP_STACK_VALIDATION=1 all"
AUTOINSTALL="yes"
CLEAN="make clean"
EOF


%clean
%__rm -rf %{buildroot}

%post -n dkms-%{pname}
# unload if existing and run
/sbin/modprobe -r uniwill_wmi > /dev/null 2>&1 || true
/sbin/modprobe -r clevo_wmi > /dev/null 2>&1 || true
/sbin/modprobe -r clevo_acpi > /dev/null 2>&1 || true
/sbin/modprobe -r tuxedo_io > /dev/null 2>&1 || true
/sbin/modprobe -r tuxedo_keyboard > /dev/null 2>&1 || true
# dkms voodoo
/usr/sbin/dkms --rpm_safe_upgrade add -m %{pname} -v %{version}-%{release}
/usr/sbin/dkms --rpm_safe_upgrade build -m %{pname} -v %{version}-%{release}
/usr/sbin/dkms --rpm_safe_upgrade install -m %{pname} -v %{version}-%{release}

if [ "$1" = 1 ]; then
/sbin/modprobe tuxedo_keyboard > /dev/null 2>&1 || true
# defined in Modules.order should load all depended modules from fresh,
# but it is not! 
/sbin/modprobe uniwill_wmi > /dev/null 2>&1 || true
/sbin/modprobe clevo_wmi > /dev/null 2>&1 || true
/sbin/modprobe clevo_acpi > /dev/null 2>&1 || true
/sbin/modprobe tuxedo_io > /dev/null 2>&1 || true
echo "tuxedo_keyboard" >> /etc/modprobe.preload
fi
# check the conf and install default config if none exist already
if [ ! -f "/etc/modprobe.d/tuxedo_keyboard.conf" ]; then
	cp -f /usr/share/tuxedo-keyboard/tuxedo_keyboard.conf /etc/modprobe.d/tuxedo_keyboard.conf
fi

%preun -n dkms-%{pname}
/sbin/modprobe -r uniwill_wmi > /dev/null 2>&1 || true
/sbin/modprobe -r clevo_wmi > /dev/null 2>&1 || true
/sbin/modprobe -r clevo_acpi > /dev/null 2>&1 || true
/sbin/modprobe -r tuxedo_io > /dev/null 2>&1 || true
/sbin/modprobe -r tuxedo_keyboard > /dev/null 2>&1 || true

/usr/sbin/dkms --rpm_safe_upgrade remove -m %{pname} -v %{version}-%{release} --all

if [ "$1" = 0 ]; then
/sbin/rmmod tuxedo_keyboard > /dev/null 2>&1
sed -i '/tuxedo_keyboard/ d' /etc/modprobe.preload
fi

%files
%defattr(-,root,root)
%doc CHANGELOG.md README.md LICENSE
%config(noreplace) %{_sysconfdir}/modprobe.d/tuxedo_keyboard.conf
%{_usrsrc}/%{pname}-%{version}-%{release}


%changelog
* Sat May 23 2022 onkelho <oh.quait at gmail.com> - 3.0.10-1pclos2022
- new version build
